<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://brewpixel.com
 * @since      1.0.0
 *
 * @package    BrewPixel_Maintenance
 * @subpackage BrewPixel_Maintenance/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    BrewPixel_Maintenance
 * @subpackage BrewPixel_Maintenance/public
 * @author     Martin Goldie <martin@brewpixel.com>
 */
class BrewPixel_Maintenance_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $brewpixel_maintenance    The ID of this plugin.
	 */
	private $brewpixel_maintenance;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $brewpixel_maintenance       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $brewpixel_maintenance, $version ) {

		$this->brewpixel_maintenance = $brewpixel_maintenance;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in BrewPixel_Maintenance_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The BrewPixel_Maintenance_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->brewpixel_maintenance, plugin_dir_url( __FILE__ ) . 'css/brewpixel-maintenance-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in BrewPixel_Maintenance_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The BrewPixel_Maintenance_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->brewpixel_maintenance, plugin_dir_url( __FILE__ ) . 'js/brewpixel-maintenance-public.js', array( 'jquery' ), $this->version, false );

	}

}
